/*
   Copyright 2024 Josh Deprez

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package router

// StringSet is a set of strings.
// Yep, yet another string set implementation. Took me 2 minutes to write *shrug*
type StringSet map[string]struct{}

func (set StringSet) ToSlice() []string {
	ss := make([]string, 0, len(set))
	for s := range set {
		ss = append(ss, s)
	}
	return ss
}

func (set StringSet) Contains(s string) bool {
	_, c := set[s]
	return c
}

func (set StringSet) Insert(ss ...string) {
	for _, s := range ss {
		set[s] = struct{}{}
	}
}

func (set StringSet) Add(t StringSet) {
	for s := range t {
		set[s] = struct{}{}
	}
}

func SetFromSlice(ss []string) StringSet {
	set := make(StringSet, len(ss))
	set.Insert(ss...)
	return set
}
